@@ -1,8 +1,9 @@
 package App::SpamcupNG::Warning;
 use strict;
 use warnings;
+use Carp qw(confess);
 
-our $VERSION = '0.017'; # VERSION
+our $VERSION = '0.018'; # VERSION
 
 =head1 NAME
 
@@ -31,8 +32,8 @@ Expects as parameter an array reference containing the associated strings.
 sub new {
     my ( $class, $message_ref ) = @_;
 
-    die 'message must be an array reference with length of at least 1'
-        unless ( ( ref($message_ref) eq 'ARRAY' )
+    confess 'message must be an array reference with length of at least 1'
+      unless ( ( ref($message_ref) eq 'ARRAY' )
         and ( scalar( @{$message_ref} ) > 0 ) );
 
     my @trimmed;
@@ -61,12 +62,12 @@ sub message {
 
 =head1 AUTHOR
 
-Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>
+Alceu Rodrigues de Freitas Junior, E<lt>glasswalk3r@yahoo.com.brE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2018 of Alceu Rodrigues de Freitas Junior,
-E<lt>arfreitas@cpan.orgE<gt>
+E<lt>glasswalk3r@yahoo.com.brE<gt>
 
 This file is part of App-SpamcupNG distribution.
 
